package com.chuanglan.shanyan_sdk_test_demo.view;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.bumptech.glide.Glide;
import com.chuanglan.shanyan_sdk.OneKeyLoginManager;
import com.chuanglan.shanyan_sdk.listener.GetPhoneInfoListener;
import com.chuanglan.shanyan_sdk.listener.InitListener;
import com.chuanglan.shanyan_sdk.listener.OneKeyLoginListener;
import com.chuanglan.shanyan_sdk.listener.OpenLoginAuthListener;
import com.chuanglan.shanyan_sdk_test_demo.BuildConfig;
import com.chuanglan.shanyan_sdk_test_demo.R;
import com.chuanglan.shanyan_sdk_test_demo.utils.ConfigUtils;

import java.text.SimpleDateFormat;

public class DebugModeActivity extends BaseActivity implements View.OnClickListener {
    private long startTime, loginTime, authTime, aunthDeltTime;
    private SharedPreferences sp;
    private TextView check_message_init, check_message;
    private String message1, message2, message3, message4, message5;
    private long time1, time2;
    private String deviceMessage;
    private RelativeLayout sdk_init, sdk_pre, sdk_login, sdk_phone;
    private ImageView loading_view;

    /**
     * 获取当前时间
     *
     * @return
     */
    public static String getCurrentTime() {
        @SuppressLint("SimpleDateFormat") SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return sdf.format(new java.util.Date());
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.shanyan_demo_activity_debug);
        initViews();
        sp = this.getSharedPreferences("auth_result", MODE_PRIVATE);
    }

    public void initViews() {
        sdk_init = findViewById(R.id.shanyan_dmeo_sdk_init);
        sdk_pre = findViewById(R.id.shanyan_dmeo_sdk_pre);
        sdk_login = findViewById(R.id.shanyan_dmeo_sdk_login);
        sdk_phone = findViewById(R.id.shanyan_dmeo_sdk_phone);
        loading_view = findViewById(R.id.shanyan_dmeo_loading_view);
        Glide.with(getApplicationContext()).load(R.drawable.shanyan_demo_loading).into(loading_view);
        loading_view.setVisibility(View.GONE);
        sdk_phone.setOnClickListener(this);
        sdk_init.setOnClickListener(this);
        sdk_pre.setOnClickListener(this);
        sdk_login.setOnClickListener(this);
        check_message_init = findViewById(R.id.shanyan_dmeo_check_message_init);
        check_message = findViewById(R.id.shanyan_dmeo_check_message);
        deviceMessage = "手机机型：" + Build.BRAND + android.os.Build.MODEL + "\n" + "android系统版本：" + android.os.Build.VERSION.RELEASE;
    }

    @Override
    public void onClick(View view) {
        if (view == null) {
            return;
        }
        switch (view.getId()) {
            case R.id.shanyan_dmeo_sdk_init:
                startNativeInit();
                break;
            case R.id.shanyan_dmeo_sdk_pre:
                startPreInit();
                break;
            case R.id.shanyan_dmeo_sdk_login:
                startAuthorityPage();
                break;
            case R.id.shanyan_dmeo_sdk_phone:
                //置换手机号
                displacePhoneNumber();
                break;
        }

    }

    private void cleanData() {
        check_message_init.setText("");
        check_message.setText("");
        message1 = "";
        message2 = "";
        message3 = "";
        message4 = "";

    }

    public void startNativeInit() {
        //闪验sdk本地数据初始化
        time1 = System.currentTimeMillis();
        OneKeyLoginManager.getInstance().init(getApplicationContext(), BuildConfig.APP_ID, new InitListener() {
            @Override
            public void getInitStatus(int code, String result) {
                cleanData();
                long costTime = System.currentTimeMillis() - time1;
                message1 = "初始化步骤：" + "\n" + "开始时间:" + getCurrentTime() + "\n" + "耗时:" + costTime + "ms" + "\n" + "日志:" + "code=" + code + "result=" + result + "\n";
                check_message_init.setText(message1);
                check_message.setText(deviceMessage);

            }
        });
    }


    public void startPreInit() {
        //设置网络初始化和预取号监听
        time2 = System.currentTimeMillis();
        //权限判断：调用网络初始化和预取号前需要获取READ_PHONE_STATE权限，否则会返回失败状态码
        //闪验SDK预取号
        OneKeyLoginManager.getInstance().getPhoneInfo(new GetPhoneInfoListener() {
            @Override
            public void getPhoneInfoStatus(int code, String result) {
                cleanData();
                long costTime = System.currentTimeMillis() - time2;
                message2 = "预取号步骤：" + "\n" + "开始时间:" + getCurrentTime() + "\n" + "耗时:" + costTime + "ms" + "\n" + "日志:" + "code=" + code + "result=" + result + "\n";
                check_message_init.setText(message1 + message2);
                check_message.setText(deviceMessage);
            }
        });
    }

    public void startAuthorityPage() {
        authTime = System.currentTimeMillis();
        loading_view.setVisibility(View.VISIBLE);
        //自定义运营商授权页界面
        OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getDialogUiConfig(getApplicationContext()));
        //开始拉取授权页
        startTime = System.currentTimeMillis();
        OneKeyLoginManager.getInstance().openLoginAuth(false, new OpenLoginAuthListener() {
            @Override
            public void getOpenLoginAuthStatus(int code, String result) {
                cleanData();
                long costTime = System.currentTimeMillis() - startTime;
                loginTime = System.currentTimeMillis();
                loading_view.setVisibility(View.GONE);
                message3 = "拉起授权页步骤：" + "\n" + "开始时间:" + getCurrentTime() + "\n" + "耗时:" + costTime + "ms" + "\n" + "日志:" + "code=" + code + "result=" + result + "\n";
                check_message_init.setText(message1 + message2 + message3);
                check_message.setText(deviceMessage);

            }
        }, new OneKeyLoginListener() {
            @Override
            public void getOneKeyLoginStatus(int code, String result) {
                cleanData();
                long costTime = System.currentTimeMillis() - loginTime;
                dataProcessing(code, result);
                loading_view.setVisibility(View.GONE);
                message4 = "点击一键登录步骤：" + "\n" + "开始时间:" + getCurrentTime() + "\n" + "耗时:" + costTime + "ms" + "\n" + "日志:" + "code=" + code + "result=" + result + "\n";
                check_message_init.setText(message1 + message2 + message3 + message4);
                check_message.setText(deviceMessage);

            }
        });//false：设置不自动销毁授权页（默认为true：自动销毁）
    }

    private void dataProcessing(int code, String result) {
        Log.e("VVV", "拉起授权页code=" + code + "result==" + result);
        //销毁授权页
        OneKeyLoginManager.getInstance().finishAuthActivity();
        OneKeyLoginManager.getInstance().removeAllListener();
        //通过edit()方法创建一个SharePreferences.Editor类的实例对象
        SharedPreferences.Editor editor = sp.edit();
        editor.putInt("code", code);
        editor.putString("result", result);
        editor.commit();
    }

    private void displacePhoneNumber() {
        aunthDeltTime = System.currentTimeMillis();
        int code = sp.getInt("code", 0);
        String result = sp.getString("result", "");
        if (!TextUtils.isEmpty(result) && 1011 != code) {
            startResultActivity(code, result);
            SharedPreferences.Editor editor = sp.edit();
            editor.putInt("code", 0);
            editor.putString("result", "");
            editor.commit();
        } else {
            message5 = "开始时间:" + getCurrentTime() + "\n" + "token为空？请先拉起授权页并点击一键登录";
            check_message_init.setText(message5);
            check_message.setText(deviceMessage);
        }
    }

    private void startResultActivity(int code, String result) {
        Intent intent = new Intent(DebugModeActivity.this, ResultActivity.class);
        intent.putExtra("type", "0");
        intent.putExtra("startTime", aunthDeltTime);
        intent.putExtra("loginResult", result);
        intent.putExtra("loginCode", code);
        startActivity(intent);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (null != loading_view) {
            loading_view.setVisibility(View.GONE);
        }
    }

    @Override
    protected void onStop() {
        super.onStop();
        if (null != loading_view) {
            loading_view.setVisibility(View.GONE);
        }
    }
}
